@@ -817,10 +817,12 @@ sub singular {
 
     my $term = $term_of{$self};
 
-    # Is it a composite possessive form???
     my $singular;
+
+    # Is it a composite possessive form???
     if ($term =~ m{ \A (.*) 's? \Z }ixms) {
-        $singular = Lingua::EN::Inflexion::Noun->new($1)->singular . q{'s};
+        my $word = Lingua::EN::Inflexion::Noun->new($1);
+        $singular = $word->is_singular ? $term : $word->singular . q{'s};
     }
 
     # Otherwise, it's either a known inflexion, or uninflected...
@@ -840,9 +842,14 @@ sub plural {
     my $term = $term_of{$self};
     my $plural = $term;
 
-    # Is it a possessive form???
-    if ($term =~ m{ \A (.*) 's? \Z }ixms) {
-        $plural = Lingua::EN::Inflexion::Noun->new($1)->plural . q{'s};
+    # Is it an unequivocally plural possessive form???
+    if ($term =~ m{ ' \Z }ixms) {
+        return $term;
+    }
+    # Is it general possessive form???
+    elsif ($term =~ m{ \A (.*) 's \Z }ixms) {
+        my $word = Lingua::EN::Inflexion::Noun->new($1);
+        $plural = $word->is_plural() ? $term : $word->plural . q{'s};
         $plural =~ s{ s's \Z }{s'}xms
     }
 
